@@ -1,6 +1,4 @@
 #
-# $Id: setup.py 86 2009-05-02 19:02:20Z lxp $
-#
 # This file is part of OpenClone.
 #
 # Copyright (C) 2009  David Gnedt
@@ -23,27 +21,6 @@ from distutils.core import setup
 import os.path
 import sys
 
-# Update svn revision if available
-if os.path.exists('.svn/entries'):
-    f = open('.svn/entries', 'r')
-    lines = f.readlines()
-    f.close()
-    rev = int(lines[3])
-    
-    lines = []
-    f = open('src/openclone/common/version.py', 'r+')
-    for line in f:
-        if line.startswith('svnrev = '):
-            lines.append('svnrev = %d\n' % rev)
-        
-        else:
-            lines.append(line)
-    
-    f.seek(0)
-    f.truncate()
-    f.writelines(lines)
-    f.close()
-
 sys.path.insert(0, 'src')
 from openclone.common import version
 sys.path.remove('src')
