@@ -1,6 +1,4 @@
 #
-# $Id: version.py 91 2009-05-02 19:11:50Z lxp $
-#
 # This file is part of OpenClone.
 #
 # Copyright (C) 2009  David Gnedt
@@ -20,8 +18,16 @@
 #
 
 major = 0
-minor = 1
+minor = 0
 patch = 0
-svnrev = 90
-version_str = '%d.%d.%d' % (major, minor, patch)
-version_long_str = '%d.%d.%d (rev %d)' % (major, minor, patch, svnrev)
+rev = 0
+dev = False
+
+if dev is True:
+	dev_str = '+dev'
+
+else:
+	dev_str = ''
+
+version_str = '%d.%d.%d%s' % (major, minor, patch, dev_str)
+version_long_str = '%d.%d.%d%s (rev %s)' % (major, minor, patch, dev_str, rev)
