@@ -1,6 +1,4 @@
 #
-# $Id: main.py 86 2009-05-02 19:02:20Z lxp $
-#
 # This file is part of OpenClone.
 #
 # Copyright (C) 2009  David Gnedt
@@ -33,27 +31,33 @@ import exception
 from ..common import version
 from compression import gzip
 from compression import lzo
-from imaging import partimage
+from imaging import dd
 from imaging import directswap
+from imaging import partimage
 from ..common.transfer import udpcast
 from misc import hash
 from partition import directpart
 
+LOG_DIR = '/var/log/openclone'
+LOCK_DIR = '/var/run/openclone'
+LOG_FILE = '%s/engine.log' % LOG_DIR
+LOCK_FILE = '%s/engine.pid' % LOCK_DIR
+
 def main():
     silent_exit = False
     url = None
     
     # Setup logging
-    if not os.path.exists('/var/log/openclone'):
+    if not os.path.exists(LOG_DIR):
         old_mask = os.umask(002)
-        os.mkdir('/var/log/openclone')
+        os.mkdir(LOG_DIR)
         os.umask(old_mask)
     
     root_logger = logging.getLogger()
     root_logger.setLevel(logging.NOTSET)
     formatter = logging.Formatter('%(asctime)s %(name)s %(levelname)s %(message)s')
     # TODO: Configuration?
-    handler = logging.FileHandler('/var/log/openclone/engine.log')
+    handler = logging.FileHandler(LOG_FILE)
     handler.setFormatter(formatter)
     root_logger.addHandler(handler)
     handler = logging.StreamHandler(sys.stderr)
@@ -65,6 +69,49 @@ def main():
     try:
         logger.info('OpenClone Engine ' + version.version_long_str)
         
+        # Check lock file
+        if not os.path.exists(LOCK_DIR):
+            old_mask = os.umask(002)
+            os.mkdir(LOCK_DIR)
+            os.umask(old_mask)
+        
+        my_pid = os.getpid()
+        
+        if os.path.exists(LOCK_FILE):
+            lock_file = open(LOCK_FILE)
+            pid_str = lock_file.read()
+            lock_file.close()
+            
+            try:
+                pid = int(pid_str)
+                if os.path.exists('/proc/%d' % pid):
+                    cmdline_file = open('/proc/%d/cmdline' % pid)
+                    cmdline = cmdline_file.read()
+                    cmdline_file.close()
+                    argv = cmdline.split('\x00')
+                    
+                    my_cmdline_file = open('/proc/%d/cmdline' % my_pid)
+                    my_cmdline = my_cmdline_file.read()
+                    my_cmdline_file.close()
+                    my_argv = my_cmdline.split('\x00')
+                    
+                    if argv[0] == my_argv[0] and argv[1] == my_argv[1]:
+                        raise Exception('OpenClone Engine is already running.')
+            
+            except ValueError, e:
+                logger.warn('Invalid lock file')
+            
+            # TODO: Upload log file for debugging?
+            
+            raw_input('Stale lock file found. Press ENTER to continue.')
+            logger.warn('Deleting stale lock file "%s".' % LOCK_FILE)
+            os.unlink(LOCK_FILE)
+        
+        # Write lock file
+        lock_file = open(LOCK_FILE, 'w')
+        lock_file.write('%d' % my_pid)
+        lock_file.close()
+        
         # TODO: Configuration?, send with logon/register response
         #root_logger.setLevel(loglevels.get(config.get('logging', 'loglevel'), logging.NOTSET))
         
@@ -178,23 +225,14 @@ def main():
                 program = operation.get_attribute_program()
                 logger.debug('Program: %s' % program)
                 if program == 'dd':
-                    # TODO: Implement dd
-                    raise exception.NextOperationException('Imaging program dd currently not implemented')
-                    #if mode == 'backup':
-                    #    proc_imaging = partimage.PartImage(partimage.MODE_BACKUP, input=operation.get_attribute_address(), output=proc_compression.getStdin())
-                    #
-                    #elif mode == 'restore':
-                    #    proc_imaging = partimage.PartImage(partimage.MODE_RESTORE, input=proc_compression.getStdout(), output=operation.get_attribute_address())
-                    #
-                    #else:
-                    #    raise exception.NextOperationException('Unknown imaging mode "%s"' % mode)
-                
-                elif program == 'partimage':
                     if mode == 'backup':
-                        proc_imaging = partimage.PartImage(partimage.MODE_BACKUP, input=operation.get_attribute_address(), output=proc_compression.getStdin())
+                        proc_imaging = dd.DD(dd.MODE_BACKUP, input=operation.get_attribute_address(), output=proc_compression.getStdin())
                     
                     elif mode == 'restore':
-                        proc_imaging = partimage.PartImage(partimage.MODE_RESTORE, input=proc_compression.getStdout(), output=operation.get_attribute_address())
+                        proc_imaging = dd.DD(dd.MODE_RESTORE, input=proc_compression.getStdout(), output=operation.get_attribute_address())
+                    
+                    else:
+                        raise exception.NextOperationException('Unknown imaging mode "%s"' % mode)
                 
                 elif program == 'directswap':
                     if mode == 'backup':
@@ -203,6 +241,13 @@ def main():
                     elif mode == 'restore':
                         proc_imaging = directswap.DirectSwap(directswap.MODE_RESTORE, input=proc_compression.getStdout(), output=operation.get_attribute_address())
                 
+                elif program == 'partimage':
+                    if mode == 'backup':
+                        proc_imaging = partimage.PartImage(partimage.MODE_BACKUP, input=operation.get_attribute_address(), output=proc_compression.getStdin())
+                    
+                    elif mode == 'restore':
+                        proc_imaging = partimage.PartImage(partimage.MODE_RESTORE, input=proc_compression.getStdout(), output=operation.get_attribute_address())
+                
                 else:
                     raise exception.NextOperationException('Unknown imaging program "%s"' % program)
                 
@@ -423,7 +468,10 @@ def main():
         raise
     
     finally:
-        if not silent_exit:
+        if silent_exit:
+            os.unlink(LOCK_FILE)
+            
+        else:
             logger.error('Unexpectedly reached end of code. Exiting...')
         
         # TODO: Cleanup threads
