@@ -1,7 +1,5 @@
 #!/bin/sh
 #
-# $Id: install.sh 86 2009-05-02 19:02:20Z lxp $
-#
 # This file is part of OpenClone.
 #
 # Copyright (C) 2009  David Gnedt
@@ -22,14 +20,22 @@
 
 # TODO: Use random temp directory names
 
-SVN_REPO="https://platinumworld.biz/svn/clone-sw"
-OPENCLONE_VER="trunk"
+HG_REPO="http://hg.savannah.nongnu.org/hgweb/openclone/"
+OPENCLONE_VER="rel"
 
-DIST_SUITE="intrepid"
+OPENCLONE_MAJOR="0"
+OPENCLONE_MINOR="1"
+OPENCLONE_PATCH="1"
+OPENCLONE_REV="109:c97c1623ab27"
+OPENCLONE_DEV="false"
+
+DIST_SUITE="jaunty"
 DIST_MIRROR="http://de.archive.ubuntu.com/ubuntu"
 CLIENT_HOSTNAME="OpenCloneClient"
 UDPCAST_VER="20081213"
 SQLALCHEMY_VER="0.4.8-1"
+KEYRING_VER="2008.03.04"
+ZSI_VER="2.0-2ubuntu4"
 
 status_text() {
 	echo -n " * $1 "
@@ -57,7 +63,7 @@ status_error() {
 }
 
 question() {
-	echo -n "$1 "
+	echo -n "   $1 "
 	read QUESTION_RET
 }
 
@@ -76,33 +82,42 @@ question_yn() {
 	done
 }
 
-status_text "Checking for your distribution..."
+STEP2=""
 
-if [ ! -f /etc/lsb-release ]; then
-	status_error "Couldn't detect your distribution."
-fi
+for ARG in "$@"; do
+	case "$ARG" in
+		--dev)
+			OPENCLONE_VER="tip"
+			;;
+		--step2)
+			STEP2="true"
+			;;
+	esac
+done
 
-DISTRIB_ID="`sed -n "s/^DISTRIB_ID=\(.*\)\$/\1/p" /etc/lsb-release`"
-DISTRIB_RELEASE="`sed -n "s/^DISTRIB_RELEASE=\(.*\)\$/\1/p" /etc/lsb-release`"
-
-echo "$DISTRIB_ID $DISTRIB_RELEASE found"
-case "$DISTRIB_ID" in
-	Ubuntu)
-		case "$DISTRIB_RELEASE" in
-			8.04)
-			# TODO: Test script on 8.10, 9.04
-				;;
-
-			*)
-				status_error "Sorry your distribution version is not supported. Please consider an upgrade."
-				;;
-		esac
-		;;
-
-	*)
-		status_error "Sorry your distribution is not supported by this installer."
-		;;
-esac
+#status_text "Checking for new installer..."
+#
+#if which wget; then
+#	LATEST_VERSION="`wget -q -O - http://openclone.nongnu.org/latest.php?mode=check&version=$OPENCLONE_VER&major=$OPENCLONE_MAJOR&minor=$OPENCLONE_MINOR&patch=$OPENCLONE_PATCH&rev=$OPENCLONE_REV&dev=$OPENCLONE_DEV`"
+#	if [ $? -ne 0 ]; then
+#		LATEST_VERSION=""
+#		status_failed "wget *FAILED*"
+#	fi
+#elif which curl; then
+#	LATEST_VERSION="`curl -s -f http://openclone.nongnu.org/latest.php?version=$OPENCLONE_VER`"
+#	if [ $? -ne 0 ]; then
+#		LATEST_VERSION=""
+#		status_failed "curl *FAILED*"
+#	fi
+#elif which lwp-request; then
+#	LATEST_VERSION="`lwp-request http://openclone.nongnu.org/latest.php?version=$OPENCLONE_VER`"
+#	if [ $? -ne 0 ]; then
+#		LATEST_VERSION=""
+#		status_failed "lwp-request *FAILED*"
+#	fi
+#else
+#	status_failed "wget, curl or lwp-request is required"
+#fi
 
 status_text "Checking for root previleges..."
 
@@ -113,11 +128,175 @@ else
 	status_error "Please execute this script with root privileges (e.g. with sudo)"
 fi
 
+status_text "Detecting installation sources..."
+echo ""
+echo ""
+
+SOURCE=""
+
+which hg > /dev/null
+if [ $? -eq 0 ]; then
+	SOURCE="hg"
+	echo "   [m] Mercurial repository (online)"
+fi
+
+for DIR in "`dirname $0`" "`dirname $0`/.." "." ".."; do
+	if [ -d "$DIR/openclone-database" -a -d "$DIR/openclone-engine" -a -d "$DIR/openclone-webinterface" -a -d "$DIR/openclone-webservice" ]; then
+		SOURCE="local"
+		echo "   [l] Local files (offline)"
+		break
+	fi
+done
+
+if [ -z "$SOURCE" ]; then
+	status_error "No installation sources found. If you want to perform an online installation you need Mercurial else you have to extract the OpenClone tar package and execute the included installer."
+fi
+
+if [ -z "$STEP2" ]; then
+	echo ""
+	question "What installation source do you want to use?"
+else
+	QUESTION_RET="m"
+fi
+
+SOURCE=""
+
+if [ "$QUESTION_RET" = "m" -o "$QUESTION_RET" = "M" ]; then
+	if [ -d /var/cache/openclone ]; then
+		(cd /var/cache/openclone && hg verify)
+		if [ $? -eq 0 ]; then
+			if [ -z "$STEP2" ]; then
+				(cd /var/cache/openclone && hg revert -a)
+				if [ $? -ne 0 ]; then
+					status_error "Unexpected Mercurial error"
+				fi
+				(cd /var/cache/openclone && hg pull "$HG_REPO")
+				if [ $? -ne 0 ]; then
+					status_error "Unexpected Mercurial error"
+				fi
+			fi
+		else
+			status_error "Unexpected cache files found. Please remove /var/cache/openclone"
+		fi
+	else
+		if [ -z "$STEP2" ]; then
+			hg clone "$HG_REPO" /var/cache/openclone
+			if [ $? -ne 0 ]; then
+				status_error "Unexpected Mercurial error"
+			fi
+		else
+			status_error "Mercurial repository not found (Step 2 failed)"
+		fi
+	fi
+	TAG_LINE="`(cd /var/cache/openclone && hg tags) | grep "^$OPENCLONE_VER" | head -n 1`"
+	TAG="`echo $TAG_LINE | awk '{ print $1 }'`"
+	REV="`echo $TAG_LINE | awk '{ print $2 }'`"
+	if [ -z "$TAG" ]; then
+		status_error "No release found"
+	fi
+	if [ -z "$STEP2" ]; then
+		(cd /var/cache/openclone && hg update -r "$TAG")
+		if [ $? -ne 0 ]; then
+			status_error "Unexpected Mercurial error"
+		fi
+		INSTALLER_FOUND=""
+		status_text "Updating installer..."
+		for INSTALLER in "$0" "`which $0`"; do
+			if [ -f "$INSTALLER" ]; then
+				INSTALLER_FOUND="true"
+				if ! cmp -s /var/cache/openclone/openclone-installer/install.sh "$INSTALLER"; then
+					cp /var/cache/openclone/openclone-installer/install.sh "$INSTALLER"
+					status_ok
+					exec sh "$INSTALLER" "$@" --step2
+				else
+					status_ok "Already up to date"
+					break
+				fi
+			fi
+		done
+		if [ -z "$INSTALLER_FOUND" ]; then
+			status_error "Installer not found"
+		fi
+	fi
+	if [ "$OPENCLONE_VER" = "tip" ]; then
+		TAG_LINE="`(cd /var/cache/openclone && hg tags) | grep "^rel" | head -n 1`"
+		TAG="`echo $TAG_LINE | awk '{ print $1 }'`"
+		OPENCLONE_DEV="true"
+	else
+		OPENCLONE_DEV="false"
+	fi
+	OPENCLONE_MAJOR="`echo $TAG | cut -b4- | cut -d "." -f 1`"
+	OPENCLONE_MINOR="`echo $TAG | cut -d "." -f 2`"
+	OPENCLONE_PATCH="`echo $TAG | cut -d "." -f 3`"
+	OPENCLONE_REV="$REV"
+	SOURCE="/var/cache/openclone"
+elif [ "$QUESTION_RET" = "l" -o "$QUESTION_RET" = "L" ]; then
+	# TODO: Fix offline installation
+	echo "WARNING: Currently a real offline installation isn't possible, you still require Internet connectivity"
+	SOURCE="$DIR"
+fi
+
+status_text "Checking for your distribution..."
+
+if [ -f /etc/lsb-release ]; then
+	DISTRIB_ID="`sed -n "s/^DISTRIB_ID=\(.*\)\$/\1/p" /etc/lsb-release`"
+	DISTRIB_RELEASE="`sed -n "s/^DISTRIB_RELEASE=\(.*\)\$/\1/p" /etc/lsb-release`"
+elif [ -f /etc/debian_version ]; then
+	DISTRIB_ID="Debian"
+	DISTRIB_RELEASE="`cat /etc/debian_version`"
+else
+	status_error "Couldn't detect your distribution."
+fi
+
+echo "$DISTRIB_ID $DISTRIB_RELEASE found"
+case "$DISTRIB_ID" in
+	Debian)
+		case "$DISTRIB_RELEASE" in
+			5.0.1|5.0.2)
+				;;
+
+			*)
+				if [ "`echo "$DISTRIB_RELEASE" | tr -d "."`" -lt 501 ]; then
+					status_error "Sorry your distribution version is not supported. Please consider an upgrade."
+				else
+					status_error "Sorry your distribution version is not supported."
+				fi
+				;;
+		esac
+		;;
+
+	Ubuntu)
+		case "$DISTRIB_RELEASE" in
+			8.04)
+			# TODO: Test script on 8.10, 9.04
+				;;
+
+			*)
+				if [ "`echo "$DISTRIB_RELEASE" | tr -d "."`" -lt 804 ]; then
+					status_error "Sorry your distribution version is not supported. Please consider an upgrade."
+				else
+					status_error "Sorry your distribution version is not supported."
+				fi
+				;;
+		esac
+		;;
+
+	*)
+		status_error "Sorry your distribution is not supported by this installer."
+		;;
+esac
+
 status_text "Checking for previous OpenClone installation..."
 
 # TODO: Optimize OpenClone installation detection
 if [ -d /etc/openclone ]; then
 	echo "found"
+	# TODO: Check if new version is available
+	#if [ "$OPENCLONE_DEV" = "true" ]; then
+	#	OPENCLONE_VER_STR="$OPENCLONE_MAJOR.$OPENCLONE_MINOR.$OPENCLONE_PATCH+dev (rev $OPENCLONE_REV)"
+	#else
+	#	OPENCLONE_VER_STR="$OPENCLONE_MAJOR.$OPENCLONE_MINOR.$OPENCLONE_PATCH (rev $OPENCLONE_REV)"
+	#fi
 	question_yn "Do you want to UPDATE your OpenClone installation?"
 	if [ "$QUESTION_RET" = "y" ]; then
 		MODE="update"
@@ -227,35 +406,41 @@ read_options() {
 	. /etc/openclone/installer.conf
 }
 
-ubuntu_update() {
-	status_text "Updating your Ubuntu system"
+deb_update() {
+	status_text "Updating your system"
 	echo ""
-	if [ -e /usr/bin/aptitude ]; then
-		aptitude update
+	aptitude update
+	if [ $? -eq 0 ]; then
 		aptitude dist-upgrade
-	elif [ -e /usr/bin/apt-get ]; then
-		apt-get update
-		apt-get dist-upgrade
 	else
-		status_error "No apt package management tool found"
+		apt-get update
+		if [ $? -eq 0 ]; then
+			apt-get dist-upgrade
+		else
+			status_error "No apt package management tool found"
+		fi
 	fi
 }
 
-ubuntu_install() {
+deb_install() {
 	status_text "Installing packages"
 	echo ""
-	if [ -e /usr/bin/aptitude ]; then
+	which aptitude > /dev/null
+	if [ $? -eq 0 ]; then
 		aptitude install "$@"
 		if [ $? -ne 0 ]; then
 			status_error "Aptitude failed"
 		fi
-	elif [ -e /usr/bin/apt-get ]; then
-		apt-get install "$@"
-		if [ $? -ne 0 ]; then
-			status_error "Apt-get failed"
-		fi
 	else
-		status_error "No apt package management tool found"
+		which apt-get > /dev/null
+		if [ $? -eq 0 ]; then
+			apt-get install "$@"
+			if [ $? -ne 0 ]; then
+				status_error "Apt-get failed"
+			fi
+		else
+			status_error "No apt package management tool found"
+		fi
 	fi
 }
 
@@ -288,9 +473,9 @@ _EOF_
 
 configure_tftpd() {
 	status_text "Configuring tftpd..."
-	# TODO: Configure TFTP server (/etc/inetd.conf or /etc/default/tftpd-hpa)
-	#/etc/init.d/openbsd-inetd reload
-	status_failed "*TODO*"
+	sed -i -e "s/^\(tftp\s\+dgram\s\+udp\s\+wait\s\+root\s\+\/usr\/sbin\/in\.tftpd \/usr\/sbin\/in\.tftpd -s \)[^\w]\+\$/\1\/tftpboot/" /etc/inetd.conf
+	status_ok
+	/etc/init.d/openbsd-inetd restart
 }
 
 configure_nfs() {
@@ -350,13 +535,16 @@ _EOF_
 
 install_engine() {
 	# Install openclone-engine
-	svn export "$SVN_REPO/$OPENCLONE_VER/openclone-engine" "$NFSROOT/tmp/openclone-engine"
+	cp -a "$SOURCE/openclone-engine" "$NFSROOT/tmp/openclone-engine"
 	if [ $? -ne 0 ]; then
-		status_error "Couldn't export OpenClone-Engine"
+		status_error "Couldn't copy OpenClone-Engine"
 	fi
-	#ssh -p "$DEV_PORT" "$DEV_USER@$DEV_HOST" "cd \"${DEV_PATH}openclone-engine\" && rm -f MANIFEST && python setup.py sdist"
-	#scp -P "$DEV_PORT" "$DEV_USER@$DEV_HOST":"${DEV_PATH}openclone-engine/dist/openclone-engine-$OPENCLONE_VER.tar.gz" "$NFSROOT/tmp"
-	#tar -xzvf "$NFSROOT/tmp/openclone-engine-$OPENCLONE_VER.tar.gz" -C "$NFSROOT/tmp"
+	if [ "$OPENCLONE_DEV" = "true" ]; then
+		DEV="True"
+	else
+		DEV="False"
+	fi
+	sed -i -e "s/^major = .*\$/major = $OPENCLONE_MAJOR/;s/^minor = .*\$/minor = $OPENCLONE_MINOR/;s/^patch = .*\$/patch = $OPENCLONE_PATCH/;s/^rev = .*\$/rev = '$OPENCLONE_REV'/;s/^dev = .*\$/dev = $DEV/" "$NFSROOT/tmp/openclone-engine/src/openclone/common/version.py"
 	chroot "$NFSROOT" sh -c "cd /tmp/openclone-engine && python setup.py install"
 	if [ $? -ne 0 ]; then
 		status_error "Couldn't install OpenClone-Engine"
@@ -378,7 +566,7 @@ setup_nfsroot() {
 	# Install base ubuntu system
 	if [ ! -e "/usr/share/debootstrap/scripts/$DIST_SUITE" ]; then
 		case "$DIST_SUITE" in
-			hardy|intrepid)
+			hardy|intrepid|jaunty)
 				if [ -e "/usr/share/debootstrap/scripts/gutsy" ]; then
 					ln -s gutsy "/usr/share/debootstrap/scripts/$DIST_SUITE"
 					if [ $? -ne 0 ]; then
@@ -393,7 +581,22 @@ setup_nfsroot() {
 				;;
 		esac
 	fi
-	debootstrap --variant=minbase --include gpgv --keyring /usr/share/keyrings/ubuntu-archive-keyring.gpg "$DIST_SUITE" "$NFSROOT" "$DIST_MIRROR"
+	OPTS="--include gpgv"
+	if [ ! -f /usr/share/keyrings/ubuntu-archive-keyring.gpg ]; then
+		wget -P /tmp "$DIST_MIRROR/pool/main/u/ubuntu-keyring/ubuntu-keyring_${KEYRING_VER}_all.deb"
+		if [ $? -ne 0 ]; then
+			status_error "Couldn't download Ubuntu-keyring"
+		fi
+		dpkg -i "/tmp/ubuntu-keyring_${KEYRING_VER}_all.deb"
+		if [ $? -ne 0 ]; then
+			status_error "Couldn't install Ubuntu-keyring"
+		fi
+		rm -f "/tmp/ubuntu-keyring_${KEYRING_VER}_all.deb"
+	fi
+	if [ -r /usr/share/keyrings/ubuntu-archive-keyring.gpg ]; then
+		OPTS="$OPTS --keyring /usr/share/keyrings/ubuntu-archive-keyring.gpg"
+	fi
+	debootstrap --variant=minbase $OPTS "$DIST_SUITE" "$NFSROOT" "$DIST_MIRROR"
 	if [ $? -ne 0 ]; then
 		status_error "Couldn't install base system"
 	fi
@@ -429,10 +632,6 @@ _EOF_
 		status_error "Couldn't write fstab"
 	fi
 
-	# Complete installation
-	#chroot "$NFSROOT" apt-get update
-	#chroot "$NFSROOT" apt-get -y --force-yes install gpgv
-
 	# Update system
 	cat << _EOF_ > "$NFSROOT/etc/apt/sources.list"
 deb $DIST_MIRROR $DIST_SUITE main universe
@@ -507,10 +706,19 @@ _EOF_
 
 	install_engine
 
-	# TODO: Setup startup script
-	#$NFSROOT/etc/event.d/tty1
-	sed -i -e "s/^exec \(.*\)\$/exec \/usr\/bin\/openclone-engine/" "$NFSROOT/etc/event.d/tty1"
-	echo "console owner" >> "$NFSROOT/etc/event.d/tty1"
+	if [ -x "$NFSROOT/usr/bin/openclone-engine" ]; then
+		OCE="\/usr\/bin\/openclone-engine"
+	elif [ -x "$NFSROOT/usr/local/bin/openclone-engine" ]; then
+		OCE="\/usr\/local\/bin\/openclone-engine"
+	else
+		status_error "Couldn't detect openclone-engine path"
+	fi
+
+	sed -i -e "s/^exec \(.*\)\$/exec $OCE/" "$NFSROOT/etc/event.d/tty1"
+	grep -q "^console owner$" "$NFSROOT/etc/event.d/tty1"
+	if [ $? -ne 0 ]; then
+		echo "console owner" >> "$NFSROOT/etc/event.d/tty1"
+	fi
 
 	# Cleanup
 	chroot "$NFSROOT" apt-get clean
@@ -551,7 +759,12 @@ setup_datapath() {
 	if [ ! -d "$DATAPATH" ]; then
 		mkdir -p "$DATAPATH"
 	fi
-	# TODO: Set permissions
+	addgroup --system openclone
+	if [ $? -ne 0 ]; then
+		status_error "Couldn't create new UNIX group openclone"
+	fi
+	chown root:openclone "$DATAPATH"
+	chmod g+w "$DATAPATH"
 	status_ok
 }
 
@@ -580,13 +793,16 @@ install_webservice() {
 	rm -f "/tmp/udpcast_${UDPCAST_VER}_i386.deb"
 
 	# Install openclone-webservice
-	svn export "$SVN_REPO/$OPENCLONE_VER/openclone-webservice" "/tmp/openclone-webservice"
+	cp -a "$SOURCE/openclone-webservice" "/tmp/openclone-webservice"
 	if [ $? -ne 0 ]; then
-		status_error "Couldn't export OpenClone-Webservice"
+		status_error "Couldn't copy OpenClone-Webservice"
 	fi
-	#ssh -p "$DEV_PORT" "$DEV_USER@$DEV_HOST" "cd \"${DEV_PATH}openclone-webservice\" && rm -f MANIFEST && python setup.py sdist"
-	#scp -P "$DEV_PORT" "$DEV_USER@$DEV_HOST":"${DEV_PATH}openclone-webservice/dist/openclone-webservice-$OPENCLONE_VER.tar.gz" "$NFSROOT/tmp"
-	#tar -xzvf "$NFSROOT/tmp/openclone-webservice-$OPENCLONE_VER.tar.gz" -C "$NFSROOT/tmp"
+	if [ "$OPENCLONE_DEV" = "true" ]; then
+		DEV="True"
+	else
+		DEV="False"
+	fi
+	sed -i -e "s/^major = .*\$/major = $OPENCLONE_MAJOR/;s/^minor = .*\$/minor = $OPENCLONE_MINOR/;s/^patch = .*\$/patch = $OPENCLONE_PATCH/;s/^rev = .*\$/rev = '$OPENCLONE_REV'/;s/^dev = .*\$/dev = $DEV/" "/tmp/openclone-webservice/src/openclone/common/version.py"
 	(cd /tmp/openclone-webservice && python setup.py install)
 	if [ $? -ne 0 ]; then
 		status_error "Couldn't install OpenClone-Webservice"
@@ -647,29 +863,23 @@ _EOF_
 		chgrp openclone /var/log/openclone
 		chmod g+w /var/log/openclone
 	fi
-	# TODO: chown root:openclone $DATAPATH
-	# TODO: chmod g+w $DATAPATH
 }
 
 install_database() {
 	echo "Installing OpenClone-Database..."
-	svn export "$SVN_REPO/$OPENCLONE_VER/openclone-database/openclone.sql" "/tmp/openclone.sql"
-	if [ $? -ne 0 ]; then
-		status_error "Couldn't export OpenClone-Database"
-	fi
-	mysql --defaults-extra-file=/etc/mysql/debian.cnf < /tmp/openclone.sql
+	mysql --defaults-extra-file=/etc/mysql/debian.cnf < "$SOURCE/openclone-database/openclone.sql"
 	if [ $? -ne 0 ]; then
 		status_error "Couldn't create database"
 	fi
-	rm -f /tmp/openclone.sql
 }
 
 install_webinterface() {
 	echo "Installing OpenClone-Webinterface..."
-	svn export "$SVN_REPO/$OPENCLONE_VER/openclone-webinterface" "/tmp/openclone-webinterface"
+	cp -a "$SOURCE/openclone-webinterface" "/tmp/openclone-webinterface"
 	if [ $? -ne 0 ]; then
-		status_error "Couldn't export OpenClone-Webinterface"
+		status_error "Couldn't copy OpenClone-Webinterface"
 	fi
+	sed -i -e "s/^\$major = .*;\$/\$major = $OPENCLONE_MAJOR;/;s/^\$minor = .*;\$/\$minor = $OPENCLONE_MINOR;/;s/^\$patch = .*;\$/\$patch = $OPENCLONE_PATCH;/;s/^\$rev = .*;\$/\$rev = '$OPENCLONE_REV';/;s/^\$dev = .*;\$/\$dev = $OPENCLONE_DEV;/" "/tmp/openclone-webinterface/src/functions/version_func.php"
 	if [ -f /var/www/openclone-webinterface/config.php ]; then
 		mv /var/www/openclone-webinterface/config.php /tmp/openclone-webinterface/src
 		if [ $? -ne 0 ]; then
@@ -739,8 +949,26 @@ case "$MODE" in
 		ask_network
 		ask_storage
 		save_options
-		ubuntu_update
-		ubuntu_install dhcp3-server tftpd-hpa nfs-kernel-server debootstrap syslinux subversion python python-mysqldb python-zsi apache2 php5 php5-mysql mysql-server
+		deb_update
+		if [ "$DISTRIB_ID" = "Debian" -a "$DISTRIB_RELEASE" = "5.0.1" ]; then
+			deb_install dhcp3-server tftpd-hpa nfs-kernel-server debootstrap syslinux iproute python python-mysqldb python-xml apache2 php5 php5-mysql mysql-server
+			wget -P /tmp "$DIST_MIRROR/pool/universe/z/zsi/python-zsi_${ZSI_VER}_all.deb"
+			if [ $? -ne 0 ]; then
+				status_error "Couldn't download ZSI"
+			fi
+			dpkg -i "/tmp/python-zsi_${ZSI_VER}_all.deb"
+			if [ $? -ne 0 ]; then
+				status_error "Couldn't install ZSI"
+			fi
+			rm -f "/tmp/python-zsi_${ZSI_VER}_all.deb"
+			which aptitude > /dev/null
+			if [ $? -eq 0 ]; then
+				aptitude hold python-zsi
+			fi
+			echo python-zsi hold | dpkg --set-selections
+		else
+			deb_install dhcp3-server tftpd-hpa nfs-kernel-server debootstrap syslinux iproute python python-mysqldb python-zsi apache2 php5 php5-mysql mysql-server
+		fi
 		/etc/init.d/apache2 restart
 		configure_dhcpd
 		setup_tftpboot
@@ -768,7 +996,7 @@ case "$MODE" in
 
 	update)
 		read_options
-		ubuntu_update
+		deb_update
 		setup_tftpboot
 		NFSROOT_DISTRIB_ID="`sed -n "s/^DISTRIB_ID=\(.*\)\$/\1/p" $NFSROOT/etc/lsb-release`"
 		NFSROOT_DISTRIB_CODENAME="`sed -n "s/^DISTRIB_CODENAME=\(.*\)\$/\1/p" $NFSROOT/etc/lsb-release`"
